function [error] = nfoldcv(n, X, y, f)
% NFOLDCV Computes n-fold CV error
%   NFOLDCV(n,X,y,b) computes n-fold balanced cross-validation
%   error with dataset X, classification y, and classification function f.
%   Returns the mean error.
%   Assumes classes in y are labeled {+1,-1}.
% 
%   Example: e = nfoldcv(5,X,y,'LDA')

ind = mod(randperm(size(X,1)), n) + 1;
errors = zeros(n,1);

for fold = 1:n
	TRind = find(ind ~= fold);
	TRX = X(TRind,:);
	TRy = y(TRind,:);

  % run the classifier on this portion of the data set
	b = feval(f, TRX, TRy);
	
	TSind = find(ind == fold);
	TSX = X(TSind,:);
	TSy = y(TSind,:);

	errors(fold) = sum(abs(((sign(TSX * b) - TSy)))./2) / size(TSy,1);
end;

error = mean(errors);
